#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 simple-smt
version:              0.9.7
visibility:           public
id:                   simple-smt-0.9.7-GZEkdMN1tkG1ckTKBNa0K0
key:                  simple-smt-0.9.7-GZEkdMN1tkG1ckTKBNa0K0
license:              BSD-3-Clause
maintainer:           iavor.diatchki@gmail.com
author:               Iavor S. Diatchki
synopsis:             A simple way to interact with an SMT solver process.
description:          A simple way to interact with an SMT solver process.
category:             Math
abi:                  55d83000667f9b22221658ed0ccb52f2
exposed:              True
exposed-modules:      SimpleSMT
import-dirs:          /usr/lib/ghc-8.10.5/site-local/simple-smt-0.9.7
library-dirs:         /usr/lib/ghc-8.10.5/site-local/simple-smt-0.9.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/simple-smt-0.9.7
hs-libraries:         HSsimple-smt-0.9.7-GZEkdMN1tkG1ckTKBNa0K0
depends:              base-4.14.2.0 process-1.6.9.0
haddock-interfaces:   /usr/share/doc/haskell-simple-smt/html/simple-smt.haddock
haddock-html:         /usr/share/doc/haskell-simple-smt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

